wt-plus
=======

wt+ is a development environment for Ubuntu Linux (soon in other linux distributions and macOS). No Vagrant, no Docker
and **automatic** `/etc/hosts` management.


Pre-alpha project
-----------------
This project still needs a lot of improvement, some manual tuning may still be required.


Installing
----------

Install and update using `pip`_:

.. code-block:: text

    $ pip install -U wt-plus

.. _pip: https://pip.pypa.io/en/stable/getting-started/
